package com.zhyc.module.dairyProducts.mapper;

import java.util.List;
import com.zhyc.module.dairyProducts.domain.XzWegihCorrection;
import org.apache.ibatis.annotations.Mapper;

/**
 * 称重校正Mapper接口
 * 
 * @author ruoyi
 * @date 2025-07-12
 */
@Mapper
public interface XzWegihCorrectionMapper 
{
    /**
     * 查询称重校正
     * 
     * @param id 称重校正主键
     * @return 称重校正
     */
    public XzWegihCorrection selectXzWegihCorrectionById(Long id);

    /**
     * 查询称重校正列表
     * 
     * @param xzWegihCorrection 称重校正
     * @return 称重校正集合
     */
    public List<XzWegihCorrection> selectXzWegihCorrectionList(XzWegihCorrection xzWegihCorrection);

    /**
     * 新增称重校正
     * 
     * @param xzWegihCorrection 称重校正
     * @return 结果
     */
    public int insertXzWegihCorrection(XzWegihCorrection xzWegihCorrection);

    /**
     * 修改称重校正
     * 
     * @param xzWegihCorrection 称重校正
     * @return 结果
     */
    public int updateXzWegihCorrection(XzWegihCorrection xzWegihCorrection);

    /**
     * 删除称重校正
     * 
     * @param id 称重校正主键
     * @return 结果
     */
    public int deleteXzWegihCorrectionById(Long id);

    /**
     * 批量删除称重校正
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteXzWegihCorrectionByIds(Long[] ids);
}
